searchData={"items":[{"type":"module","title":"Introspex","doc":"Introspex generates Ecto schemas from existing PostgreSQL databases.\n\nThis library introspects your PostgreSQL database and generates Ecto schema\nfiles with proper field types, associations, and changesets. It supports:\n\n- Tables, views, and materialized views\n- Automatic association detection (belongs_to, has_many, many_to_many)\n- Comprehensive type mapping (UUID, arrays, JSON, enums, PostGIS)\n- Changeset generation with validations\n- Modern Ecto best practices","ref":"Introspex.html"},{"type":"module","title":"Usage - Introspex","doc":"Generate schemas for all tables and views:\n\n    mix ecto.gen.schema --repo MyApp.Repo\n\nGenerate for a specific table:\n\n    mix ecto.gen.schema --repo MyApp.Repo --table users\n\nSee `Mix.Tasks.Ecto.Gen.Schema` for all available options.","ref":"Introspex.html#module-usage"},{"type":"function","title":"Introspex.version/0","doc":"Returns the current version of Introspex.","ref":"Introspex.html#version/0"},{"type":"module","title":"Introspex.ContextBuilder","doc":"Generates Phoenix context modules with CRUD functions for database tables.\n\nContext modules provide a boundary layer between your web interface and data layer,\norganizing related functionality together. This module generates context files that\ninclude standard CRUD operations, with special handling for views that only get\nread operations.","ref":"Introspex.ContextBuilder.html"},{"type":"function","title":"Introspex.ContextBuilder.build_context/3","doc":"Builds a Phoenix context module with CRUD functions for the given schemas.","ref":"Introspex.ContextBuilder.html#build_context/3"},{"type":"function","title":"Parameters - Introspex.ContextBuilder.build_context/3","doc":"* `context_name` - The name of the context (e.g., \"Accounts\", \"Blog\")\n  * `schemas` - List of schema information maps containing:\n    * `:module_name` - The schema module name\n    * `:singular_name` - Singular form of the resource name\n    * `:plural_name` - Plural form of the resource name\n    * `:table_type` - Type of database object (:table, :view, or :materialized_view)\n  * `opts` - Keyword list of options:\n    * `:app_name` - The application name\n    * `:repo_module` - The Repo module name\n    * `:path` - Optional path segments to include in module name","ref":"Introspex.ContextBuilder.html#build_context/3-parameters"},{"type":"function","title":"Examples - Introspex.ContextBuilder.build_context/3","doc":"build_context(\"Accounts\", schemas, app_name: \"MyApp\", repo_module: \"MyApp.Repo\")\n\nReturns a string containing the complete context module code.","ref":"Introspex.ContextBuilder.html#build_context/3-examples"},{"type":"module","title":"Introspex.Postgres.Introspector","doc":"Introspects PostgreSQL database schema including tables, views, materialized views,\ncolumns, constraints, and foreign keys.","ref":"Introspex.Postgres.Introspector.html"},{"type":"function","title":"Introspex.Postgres.Introspector.decode_action/1","doc":"Decodes PostgreSQL foreign key action codes to atoms.","ref":"Introspex.Postgres.Introspector.html#decode_action/1"},{"type":"function","title":"Introspex.Postgres.Introspector.get_check_constraints/3","doc":"Gets check constraints for a table.","ref":"Introspex.Postgres.Introspector.html#get_check_constraints/3"},{"type":"function","title":"Introspex.Postgres.Introspector.get_columns/3","doc":"Gets detailed column information for a specific table.","ref":"Introspex.Postgres.Introspector.html#get_columns/3"},{"type":"function","title":"Introspex.Postgres.Introspector.get_foreign_keys/3","doc":"Gets foreign key relationships for a table.","ref":"Introspex.Postgres.Introspector.html#get_foreign_keys/3"},{"type":"function","title":"Introspex.Postgres.Introspector.get_indexes/3","doc":"Gets indexes for a table.","ref":"Introspex.Postgres.Introspector.html#get_indexes/3"},{"type":"function","title":"Introspex.Postgres.Introspector.get_primary_keys/3","doc":"Gets primary key information for a table.","ref":"Introspex.Postgres.Introspector.html#get_primary_keys/3"},{"type":"function","title":"Introspex.Postgres.Introspector.get_unique_constraints/3","doc":"Gets unique constraints for a table (excluding primary key).","ref":"Introspex.Postgres.Introspector.html#get_unique_constraints/3"},{"type":"function","title":"Introspex.Postgres.Introspector.list_tables/3","doc":"Lists all tables, views, and materialized views in the specified schema.","ref":"Introspex.Postgres.Introspector.html#list_tables/3"},{"type":"function","title":"Introspex.Postgres.Introspector.parse_default/1","doc":"Parses PostgreSQL default values, removing type casts and sequence defaults.","ref":"Introspex.Postgres.Introspector.html#parse_default/1"},{"type":"module","title":"Introspex.Postgres.RelationshipAnalyzer","doc":"Analyzes foreign key relationships between tables to determine\nEcto associations (belongs_to, has_many, has_one, many_to_many).","ref":"Introspex.Postgres.RelationshipAnalyzer.html"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.analyze_belongs_to/2","doc":"Analyzes belongs_to relationships based on foreign keys in the current table.","ref":"Introspex.Postgres.RelationshipAnalyzer.html#analyze_belongs_to/2"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.analyze_has_many/4","doc":"Analyzes has_many relationships by looking for foreign keys in other tables\nthat reference this table.","ref":"Introspex.Postgres.RelationshipAnalyzer.html#analyze_has_many/4"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.analyze_has_one/4","doc":"Analyzes has_one relationships (similar to has_many but with singular naming).","ref":"Introspex.Postgres.RelationshipAnalyzer.html#analyze_has_one/4"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.analyze_many_to_many/4","doc":"Analyzes many_to_many relationships by detecting join tables.","ref":"Introspex.Postgres.RelationshipAnalyzer.html#analyze_many_to_many/4"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.analyze_relationships/4","doc":"Analyzes all relationships for a given table and returns association definitions.","ref":"Introspex.Postgres.RelationshipAnalyzer.html#analyze_relationships/4"},{"type":"function","title":"Introspex.Postgres.RelationshipAnalyzer.join_table?/3","doc":"Determines if a table is likely a join table for many-to-many relationships.","ref":"Introspex.Postgres.RelationshipAnalyzer.html#join_table?/3"},{"type":"module","title":"Introspex.Postgres.TypeMapper","doc":"Maps PostgreSQL data types to Ecto schema types.","ref":"Introspex.Postgres.TypeMapper.html"},{"type":"function","title":"Introspex.Postgres.TypeMapper.ecto_timestamp_field?/1","doc":"Determines if a field is an Ecto timestamp field.\nEcto specifically expects \"inserted_at\" and \"updated_at\" for the timestamps() macro.\nThis is not domain-specific but rather an Ecto framework convention.","ref":"Introspex.Postgres.TypeMapper.html#ecto_timestamp_field?/1"},{"type":"function","title":"Introspex.Postgres.TypeMapper.ecto_timestamps_compatible?/1","doc":"Checks if columns are compatible with Ecto's timestamps() macro.\nReturns true only if both inserted_at and updated_at exist with compatible types.","ref":"Introspex.Postgres.TypeMapper.html#ecto_timestamps_compatible?/1"},{"type":"function","title":"Introspex.Postgres.TypeMapper.map_type/3","doc":"Maps a PostgreSQL data type string to an Ecto type atom or tuple.","ref":"Introspex.Postgres.TypeMapper.html#map_type/3"},{"type":"function","title":"Introspex.Postgres.TypeMapper.postgis_types/0","doc":"Returns a list of supported PostGIS types that require special handling.","ref":"Introspex.Postgres.TypeMapper.html#postgis_types/0"},{"type":"function","title":"Introspex.Postgres.TypeMapper.requires_special_import?/1","doc":"Checks if a type requires a special import or alias.","ref":"Introspex.Postgres.TypeMapper.html#requires_special_import?/1"},{"type":"function","title":"Introspex.Postgres.TypeMapper.type_to_string/1","doc":"Returns the Ecto field type definition as a string for code generation.","ref":"Introspex.Postgres.TypeMapper.html#type_to_string/1"},{"type":"module","title":"Introspex.SchemaBuilder","doc":"Builds Ecto schema definitions from database introspection data.","ref":"Introspex.SchemaBuilder.html"},{"type":"function","title":"Introspex.SchemaBuilder.build_schema/3","doc":"Builds a complete schema module from table metadata.","ref":"Introspex.SchemaBuilder.html#build_schema/3"},{"type":"task","title":"mix ecto.gen.schema","doc":"Generates Ecto schemas from an existing PostgreSQL database.\n\nThis task introspects your PostgreSQL database and generates Ecto schema\nfiles with proper field types, associations, and changesets.","ref":"Mix.Tasks.Ecto.Gen.Schema.html"},{"type":"task","title":"Examples - mix ecto.gen.schema","doc":"$ mix ecto.gen.schema --repo MyApp.Repo\n    $ mix ecto.gen.schema --repo MyApp.Repo --schema public --table users\n    $ mix ecto.gen.schema --repo MyApp.Repo --exclude-views\n    $ mix ecto.gen.schema --repo MyApp.Repo --binary-id --dry-run\n    $ mix ecto.gen.schema --repo MyApp.Repo --context Accounts --context-tables users,profiles\n    $ mix ecto.gen.schema --repo MyApp.Repo --context Blog --context-tables posts,comments,tags","ref":"Mix.Tasks.Ecto.Gen.Schema.html#module-examples"},{"type":"task","title":"Options - mix ecto.gen.schema","doc":"* `--repo` - the repository module (required)\n  * `--schema` - PostgreSQL schema name (default: \"public\")\n  * `--table` - generate schema for a specific table only\n  * `--exclude-views` - skip generating schemas for views and materialized views\n  * `--binary-id` - use binary_id (UUID) for primary keys\n  * `--no-timestamps` - do not generate timestamps() in schemas\n  * `--no-changesets` - skip generating changeset functions\n  * `--no-associations` - skip detecting and generating associations\n  * `--module-prefix` - prefix for generated module names (default: app name)\n  * `--output-dir` - output directory for schema files (default: lib/app_name)\n  * `--dry-run` - preview what would be generated without writing files\n  * `--context` - Phoenix context name for organizing related schemas\n  * `--context-tables` - comma-separated list of tables to include in the context (only these tables will be generated)\n  * `--path` - custom path segment(s) to insert in the output directory (e.g., \"queries\" results in lib/app_name/queries/...)","ref":"Mix.Tasks.Ecto.Gen.Schema.html#module-options"},{"type":"extras","title":"Introspex","doc":"# Introspex\n\nGenerate Ecto schemas from existing PostgreSQL databases - including support for tables, views, materialized views, associations, and modern Ecto features.\n\n**Perfect for migrating existing applications to Elixir** - Whether you're moving from Rails, Django, or any other framework with an existing PostgreSQL database or are using an external migration tool (i.e., not ecto migrations), Introspex helps you quickly generate Elixir/Ecto schemas that match your current database structure.","ref":"readme.html"},{"type":"extras","title":"Installation - Introspex","doc":"Add `introspex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:introspex, \"~> 0.2.0\", only: :dev}]\nend\n```\n\nThen run:\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Introspex","doc":"#","ref":"readme.html#usage"},{"type":"extras","title":"Basic Usage - Introspex","doc":"Generate schemas for all tables and views in your database:\n\n```bash\nmix ecto.gen.schema --repo MyApp.Repo\n```\n\n#","ref":"readme.html#basic-usage"},{"type":"extras","title":"Generate for a Specific Table - Introspex","doc":"```bash\nmix ecto.gen.schema --repo MyApp.Repo --table users\n```\n\n#","ref":"readme.html#generate-for-a-specific-table"},{"type":"extras","title":"Exclude Views - Introspex","doc":"By default, views and materialized views are included. To exclude them:\n\n```bash\nmix ecto.gen.schema --repo MyApp.Repo --exclude-views\n```\n\n#","ref":"readme.html#exclude-views"},{"type":"extras","title":"Use Binary IDs (UUIDs) - Introspex","doc":"Generate schemas with UUID primary keys:\n\n```bash\nmix ecto.gen.schema --repo MyApp.Repo --binary-id\n```\n\n#","ref":"readme.html#use-binary-ids-uuids"},{"type":"extras","title":"Dry Run - Introspex","doc":"Preview what will be generated without creating files:\n\n```bash\nmix ecto.gen.schema --repo MyApp.Repo --dry-run\n```\n\n#","ref":"readme.html#dry-run"},{"type":"extras","title":"Phoenix Contexts - Introspex","doc":"Generate schemas organized into Phoenix contexts. When using `--context-tables`, only the specified tables will be generated:\n\n```bash\n# Generate ONLY users and profiles tables in the Accounts context\nmix ecto.gen.schema --repo MyApp.Repo --context Accounts --context-tables users,profiles\n\n# Generate ONLY posts, comments, and tags tables in the Blog context\nmix ecto.gen.schema --repo MyApp.Repo --context Blog --context-tables posts,comments,tags\n```\n\nWhen using contexts:\n- A context module is generated at `lib/my_app/accounts.ex` with CRUD functions\n- Schemas are organized into subdirectories:\n  - `lib/my_app/accounts/user.ex` for `MyApp.Accounts.User`\n  - `lib/my_app/accounts/profile.ex` for `MyApp.Accounts.Profile`\n- Views and materialized views only get read operations (list and get) in the context module\n- Duplicate function names are automatically prevented when tables have the same singular form (e.g., `user_account` and `user_accounts`)\n\n#","ref":"readme.html#phoenix-contexts"},{"type":"extras","title":"Custom Paths - Introspex","doc":"Use the `--path` option to organize schemas in custom directory structures. Path segments are reflected in module names:\n\n```bash\n# Simple path - generates Services.Queries.Property module\nmix ecto.gen.schema --repo Services.Repo --path queries --table property\n\n# Path with underscores - generates MyApp.SomePath.User module  \nmix ecto.gen.schema --repo MyApp.Repo --path some_path --table users\n\n# Multiple path segments - generates MyApp.Admin.Reports.Metric module\nmix ecto.gen.schema --repo MyApp.Repo --path admin/reports --table metrics\n```\n\nCombine with contexts for organized domain structure:\n\n```bash\n# Generates lib/my_app/queries/accounts.ex and lib/my_app/queries/accounts/user.ex\n# Modules: MyApp.Queries.Accounts and MyApp.Queries.Accounts.User\nmix ecto.gen.schema --repo MyApp.Repo --path queries --context Accounts --context-tables users,profiles\n```","ref":"readme.html#custom-paths"},{"type":"extras","title":"Options - Introspex","doc":"- `--repo` - The repository module (required)\n- `--schema` - PostgreSQL schema name (default: \"public\")\n- `--table` - Generate schema for a specific table only\n- `--exclude-views` - Skip generating schemas for views and materialized views\n- `--binary-id` - Use binary_id (UUID) for primary keys\n- `--no-timestamps` - Do not generate timestamps() in schemas\n- `--no-changesets` - Skip generating changeset functions\n- `--no-associations` - Skip detecting and generating associations\n- `--module-prefix` - Prefix for generated module names (default: app name)\n- `--output-dir` - Output directory for schema files (default: lib/app_name)\n- `--dry-run` - Preview what would be generated without writing files\n- `--context` - Phoenix context name for organizing related schemas\n- `--context-tables` - Comma-separated list of tables to include in the context (when specified, only these tables will be generated)\n- `--path` - Custom path segment(s) to insert in the output directory (e.g., \"queries\" results in lib/app_name/queries/...)","ref":"readme.html#options"},{"type":"extras","title":"Example Output - Introspex","doc":"For a `users` table with foreign keys and constraints:\n\n```elixir\ndefmodule MyApp.User do\n  @moduledoc false\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"users\" do\n    field :email, :string\n    field :name, :string\n    field :age, :integer\n    field :bio, :string\n    field :activated_at, :utc_datetime\n    field :roles, {:array, :string}\n    field :status, Ecto.Enum, values: [:active, :inactive, :pending]\n    \n    belongs_to :company, MyApp.Company\n    has_many :posts, MyApp.Post, foreign_key: :author_id\n    many_to_many :teams, MyApp.Team, join_through: \"users_teams\"\n    \n    timestamps()\n  end\n\n  @doc false\n  def changeset(user, attrs) do\n    user\n    |> cast(attrs, [:email, :name, :age, :bio, :activated_at, :roles, :status, :company_id])\n    |> validate_required([:email, :name])\n    |> validate_format(:email, ~r/@/)\n    |> unique_constraint(:email)\n    |> foreign_key_constraint(:company_id)\n  end\nend\n```\n\nFor a database view:\n\n```elixir\ndefmodule MyApp.UserStats do\n  @moduledoc \"Schema for database view\"\n  use Ecto.Schema\n\n  @schema_source_type :view\n\n  schema \"user_stats\" do\n    field :user_id, :integer\n    field :posts_count, :integer\n    field :comments_count, :integer\n    field :last_activity, :utc_datetime\n  end\nend\n```","ref":"readme.html#example-output"},{"type":"extras","title":"Supported Types - Introspex","doc":"The generator supports all common PostgreSQL types including:\n\n- **Basic Types**: integer, text, boolean, decimal, float\n- **Date/Time**: date, time, timestamp, timestamptz\n- **UUID**: uuid → :binary_id\n- **JSON**: json, jsonb → (requires manual type specification, see below)\n- **Arrays**: integer[], text[] → {:array, :type}\n- **Enums**: PostgreSQL enums → Ecto.Enum\n- **PostGIS**: geometry, geography types\n- **Network**: inet, cidr, macaddr\n- **Special**: money, interval, tsvector","ref":"readme.html#supported-types"},{"type":"extras","title":"Mixed Foreign Key Types - Introspex","doc":"When your database uses a mix of UUID and integer primary keys, Introspex automatically handles the type declarations. For example, if a table with UUID primary keys has a foreign key to a table with integer primary keys, the generator will add the appropriate `type: :id` option:\n\n```elixir\n@primary_key {:id, :binary_id, autogenerate: false}\n@foreign_key_type :binary_id\n\nschema \"organizations\" do\n  # This foreign key is an integer, so type: :id is added automatically\n  belongs_to :organization_role, MyApp.OrganizationRole, type: :id\n  \n  # These foreign keys are UUIDs, so they use the default @foreign_key_type\n  belongs_to :user, MyApp.User\n  belongs_to :account, MyApp.Account\nend\n```","ref":"readme.html#mixed-foreign-key-types"},{"type":"extras","title":"JSON/JSONB Fields - Introspex","doc":"PostgreSQL's JSON and JSONB columns can store various data structures (objects, arrays, primitives), making it impossible to automatically determine the correct Ecto type. Therefore, these fields are commented out in generated schemas with examples to guide you:\n\n```elixir\n# JSONB field - requires manual type specification based on your data:\n# field :contact_ids, :map                    # For JSON objects: {\"key\": \"value\"}\n# field :contact_ids, {:array, :string}       # For string arrays: [\"value1\", \"value2\"]\n# field :contact_ids, {:array, :integer}      # For integer arrays: [1, 2, 3]\n# field :contact_ids, {:array, :map}          # For object arrays: [{\"id\": 1}, {\"id\": 2}]\n```\n\nYou'll need to:\n1. Uncomment the field\n2. Choose the appropriate type based on your actual data structure\n3. Update the changeset function to include the field\n\nCommon patterns:\n- Use `:map` for JSON objects/documents\n- Use `{:array, :string}` for arrays of UUIDs or strings\n- Use `{:array, :integer}` for arrays of numeric IDs\n- Use `{:array, :map}` for arrays of objects","ref":"readme.html#json-jsonb-fields"},{"type":"extras","title":"Requirements - Introspex","doc":"- Elixir 1.14+\n- Ecto 3.10+\n- PostgreSQL 12+","ref":"readme.html#requirements"},{"type":"extras","title":"Contributing - Introspex","doc":"1. Fork it\n2. Create your feature branch (`git checkout -b feature/my-new-feature`)\n3. Commit your changes (`git commit -am 'Add some feature'`)\n4. Push to the branch (`git push origin feature/my-new-feature`)\n5. Create new Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Acknowledgments - Introspex","doc":"Introspex was inspired by [ecto_generator](https://github.com/alexandrubagu/ecto_generator) created by [Alexandru Bogdan Bâgu](https://github.com/alexandrubagu). While Introspex is a complete rewrite with a different approach and feature set, the original project provided valuable inspiration for the concept of generating Ecto schemas from existing databases.\n\nMaintained by [Chase Pursley](https://github.com/cpursley).","ref":"readme.html#acknowledgments"},{"type":"extras","title":"License - Introspex","doc":"MIT License - see LICENSE file for details","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.0] - 2025-01-06\n\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Phoenix context support with `--context` and `--context-tables` CLI options\n  - Generate schemas organized into Phoenix contexts\n  - Generates a context module file with CRUD functions (e.g., `lib/my_app/accounts.ex`)\n  - Specify which tables belong to each context\n  - Schemas are automatically placed in context subdirectories\n  - When `--context-tables` is specified, only those tables will be generated\n  - Views and materialized views only generate read operations (list and get)\n  - Example: `--context Accounts --context-tables users,profiles`\n- Custom path support with `--path` CLI option\n  - Organize schemas in custom directory structures\n  - Supports multiple path segments (e.g., `--path admin/reports`)\n  - Works with contexts for flexible organization\n  - Path segments are reflected in module names (e.g., `--path queries` → `MyApp.Queries.ModuleName`)\n  - Example: `--path queries --context Accounts`\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- JSON/JSONB fields now generate as commented code with manual type instructions\n  - Prevents runtime errors from incorrect type assumptions\n  - Users must manually specify the correct type based on their data structure\n  - Supports common patterns: objects, string arrays, integer arrays, etc.\n  - Added comprehensive documentation and examples in generated code\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- JSON/JSONB field handling to avoid runtime errors\n- Improved type safety for complex PostgreSQL types\n- Context modules now only generate read operations for views and materialized views\n- Fixed duplicate alias compilation errors by using grouped alias syntax for multiple schemas\n- Fixed duplicate function definitions in context modules when tables have the same singular form (e.g., `user_account` and `user_accounts`)\n- Removed invalid `@schema_source_type` attribute for views/materialized views - added comment instead\n- Added comprehensive documentation to all public functions\n- Fixed unused alias warnings in context modules by only aliasing schemas that are actually used in generated functions\n- Simplified association module references - now uses just the schema name instead of relative module paths\n- Fixed association module references to use full module paths when generating schemas within contexts\n- Fixed mixed foreign key type handling - automatically adds `type: :id` to belongs_to associations when foreign key is integer but schema uses binary_id\n\n## [0.1.0] - 2025-01-05\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Initial Release - Changelog","doc":"Introspex is a new Elixir library for generating Ecto schemas from existing PostgreSQL databases. While inspired by the original [ecto_generator](https://github.com/alexandrubagu/ecto_generator), Introspex is a complete rewrite with a focus on modern PostgreSQL and Ecto practices.\n\n#","ref":"changelog.html#initial-release"},{"type":"extras","title":"Features - Changelog","doc":"- Generate Ecto schemas from PostgreSQL tables, views, and materialized views\n- Automatic association detection based on foreign keys\n- Intelligent changeset generation with validations\n- Comprehensive PostgreSQL type support including:\n  - UUID primary keys with auto-detection\n  - Arrays (both `[]` and `_` notation)\n  - JSON/JSONB fields\n  - Enums\n  - PostGIS geometry types\n  - Network types (inet, cidr, macaddr)\n  - All standard SQL types\n- Smart handling of database defaults - lets PostgreSQL manage them\n- Proper timestamp detection - only uses `timestamps()` for Ecto-compatible columns\n- Support for composite primary keys\n- Dry-run mode for previewing generated schemas\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Fixed Issues (from initial development) - Changelog","doc":"- Repo startup error handling for umbrella applications\n- String interpolation in schema generation\n- Proper UUID primary key detection and configuration\n- PostgreSQL array type handling with underscore prefix\n- Foreign key field deduplication with belongs_to associations\n- Timestamp field detection for non-standard column names\n- Database default value handling to prevent Ecto conflicts\n\n#","ref":"changelog.html#fixed-issues-from-initial-development"},{"type":"extras","title":"Requirements - Changelog","doc":"- Elixir 1.14+\n- Ecto 3.10+\n- PostgreSQL 12+\n\n#","ref":"changelog.html#requirements"},{"type":"extras","title":"Acknowledgments - Changelog","doc":"Inspired by [ecto_generator](https://github.com/alexandrubagu/ecto_generator) by Alexandru Bogdan Bâgu.","ref":"changelog.html#acknowledgments"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}